@@ -1,4 +1,3 @@
-from .tile import *
 from .board import *
 from .wall import *
 from .meld import *
@@ -8,4 +7,7 @@ from .call import *
 from .match import *
 from .boardmanager import *
 from .gameevent import *
-from .dialogmanager import *
\ No newline at end of file
+from .dialogmanager import *
+from .playermanager import *
+from .storagemanager import *
+from .stubbornbot import *
